CwDexError

Enum CwDexError 

pub enum CwDexError {
Show 17 variants Std(StdError), TryFromIntError(TryFromIntError), Overflow(OverflowError), DivideByZero(DivideByZeroError), Infallible(Infallible), InvalidOutAsset {}, InvalidInAsset { a: Asset, }, InvalidLpToken {}, BigIntOverflow {}, InvalidZeroAmount {}, LiquidityAmountTooSmall {}, InvalidProvideLPsWithSingleToken {}, NotLpToken {}, UnstakingDurationNotSupported {}, MinOutNotReceived { min_out: Uint128, received: Uint128, }, AddressParsingErrors { token_denom: String, }, UnsupportedArguments { reason: String, },
}
Description

This enum describes router-test contract errors!

Variants



Std(StdError)

Converts from cosmwasm_std::StdError



TryFromIntError(TryFromIntError)

Converts from std::num::TryFromIntError



Overflow(OverflowError)

Converts from cosmwasm_std::OverflowError



DivideByZero(DivideByZeroError)

Converts from cosmwasm_std::DivideByZeroError



Infallible(Infallible)

Converts from std::convert::Infallible



InvalidOutAsset

Invalid Reply ID Error



InvalidInAsset

Invalid input asset

Fields

a: Asset

The asset in question



InvalidLpToken

Invalid LP token



BigIntOverflow

Overflow when converting to from BigInt to Uint128



InvalidZeroAmount

Zero funds transfer



LiquidityAmountTooSmall

Insufficient amount of liquidity



InvalidProvideLPsWithSingleToken

Results from single-sided entry into empty pool



NotLpToken

Asset is not an LP token



UnstakingDurationNotSupported

When unstaking/unbonding is expected to be instant



MinOutNotReceived

The minimum amount of tokens requested was not returned from the action

Fields

min_out: Uint128

The minimum amount of tokens the user requested

received: Uint128

The actual amount of tokens received



AddressParsingErrors

For when the token_denom can’t be parsed

Fields

token_denom: String

The token_denom that couldn’t be parsed



UnsupportedArguments

For when min_out is set for concentrated liquidity pools, as they do not support min_out

Fields

reason: String

The reason that explains why the arguments are unsupported